@@ -30,9 +30,8 @@ processSDA_WKT <- function(d, g='geom', crs = 4326, p4s = NULL, as_sf = TRUE) {
   }
 
   # convert wkt to sf/SPDF
-  d[[g]] <- sf::st_as_sfc(wk::as_wkt(d[,g]))
+  d[[g]] <- sf::st_as_sfc(d[,g], crs = crs)
   sfobj <- sf::st_as_sf(d)
-  sfobj <- sf::st_set_crs(sfobj, sf::st_crs(crs))
   if (as_sf) {
     return(sfobj)
   }
@@ -147,13 +146,14 @@ FROM geom_data;
 #' @param byFeature Iterate over features, returning a combined data.frame where each feature is uniquely identified by value in `idcol`. Default `FALSE`.
 #' @param idcol Unique IDs used for individual features when `byFeature = TRUE`; Default `"gid"`
 #' @param query_string Default: `FALSE`; if `TRUE` return a character string containing query that would be sent to SDA via `SDA_query`
-#' @return A `data.frame` if `what = 'mukey'`, otherwise a `SpatialPolygonsDataFrame` or `sf` object.
+#' @param as_Spatial Return sp classes? e.g. `Spatial*DataFrame`. Default: `FALSE`.
+#' @return A `data.frame` if `what = 'mukey'`, otherwise an `sf` object.
 #' @note Row-order is not preserved across features in \code{geom} and returned object. Use `byFeature` argument to iterate over features and return results that are 1:1 with the inputs. Polygon area in acres is computed server-side when `what = 'mupolygon'` and `geomIntersection = TRUE`.
 #' @author D.E. Beaudette, A.G. Brown, D.R. Schlaepfer
 #' @seealso \code{\link{SDA_query}}
 #' @keywords manip
 #' @examples
-#' \donttest{
+#' \dontrun{
 #'   if (requireNamespace("aqp") && requireNamespace("sf")) {
 #'
 #'     library(aqp)
@@ -291,7 +291,8 @@ SDA_spatialQuery <- function(geom,
                              db = c("SSURGO", "STATSGO", "SAPOLYGON"),
                              byFeature = FALSE,
                              idcol = "gid",
-                             query_string = FALSE) {
+                             query_string = FALSE,
+                             as_Spatial = getOption('soilDB.return_Spatial', default = FALSE)) {
   if (byFeature) {
     res <- do.call('rbind', lapply(1:nrow(geom), function(i) {
       res2 <- .SDA_spatialQuery(
@@ -306,37 +307,64 @@ SDA_spatialQuery <- function(geom,
     }))
     return(res)
   }
-  .SDA_spatialQuery(
+
+  res <- .SDA_spatialQuery(
     geom = geom,
     what = what,
     geomIntersection = geomIntersection,
     db = db,
     query_string = query_string
   )
+
+  # flag for Spatial result
+  if (as_Spatial && requireNamespace("sf")) {
+    res <- sf::as_Spatial(res)
+  }
+  res
 }
+
 .SDA_spatialQuery <- function(geom,
                              what = 'mukey',
                              geomIntersection = FALSE,
                              db = c("SSURGO", "STATSGO", "SAPOLYGON"),
                              query_string = FALSE) {
+
   # check for required packages
   if (!requireNamespace('sf', quietly = TRUE))
-    stop('please install the `sf` package', call.=FALSE)
+    stop('please install the `sf` package', call. = FALSE)
 
   if (!requireNamespace('wk', quietly = TRUE))
-    stop('please install the `wk` package', call.=FALSE)
+    stop('please install the `wk` package', call. = FALSE)
 
   what <- tolower(what)
   db <- toupper(db)
 
-  # sp support
   return_sf <- FALSE
-  if (inherits(geom, 'sf') || inherits(geom, 'sfc')) {
+  return_terra <- FALSE
+
+  # raster support
+  if (inherits(geom, 'RasterLayer') |
+      inherits(geom, 'RasterBrick') |
+      inherits(geom, 'RasterStack')) {
+    if (!requireNamespace('terra'))
+      stop("packages terra is required", call. = FALSE)
+    geom <- terra::rast(geom)
+  }
+
+  if (inherits(geom, 'SpatRaster') | inherits(geom, 'SpatVector')) {
+    # terra support
+    return_terra <- TRUE
+    return_sf <- TRUE
+    geom <- terra::as.polygons(terra::ext(geom),
+                               crs = terra::crs(geom))
+    geom <- sf::st_as_sf(geom)
+  } else if (inherits(geom, 'sf') || inherits(geom, 'sfc')) {
     return_sf <- TRUE
   } else if (inherits(geom, 'Spatial')) {
+    # sp support
     geom <- sf::st_as_sf(geom)
   } else {
-    stop('`geom` must be an sf or Spatial* object', call. = FALSE)
+    stop('`geom` must be an sf, terra, or Spatial* object', call. = FALSE)
   }
 
   # backwards compatibility with old value of what argument
@@ -402,6 +430,10 @@ SDA_spatialQuery <- function(geom,
     # note that row-order / number of rows in results may not match geom
     res <- suppressMessages(SDA_query(q))
     res <- processSDA_WKT(res, as_sf = return_sf)
+    if (return_terra) {
+      # sf -> terra
+      res <- terra::vect(res)
+    }
   }
 
   if (what == 'mukey') {
