@@ -1,6 +1,6 @@
 
 .fetchNASIS_report <- function(url = NULL,
-                               rmHzErrors       = TRUE,
+                               rmHzErrors       = FALSE,
                                nullFragsAreZero = TRUE,
                                soilColorState   = "moist",
                                stringsAsFactors = NULL
@@ -42,13 +42,13 @@
       # aggregate NASIS returns empty rows
       # NASIS text reports return empty columns
       # remove
-      x2 <- x2[!is.na(x2$peiid), - ncol(x2)]
+      x2 <- x2[!is.na(x2$peiid), -ncol(x2)]
       idx <- names(x2) %in% c("pmkind", "pmorigin")
-      x2[!idx] <- uncode(x2[!idx], db = "LIMS")
+      x2[!idx] <- uncode(x2[!idx])
       idx <- sapply(x2, is.character)
       x2[idx] <- lapply(x2[idx], function(x) ifelse(x == "", NA, x))
       return(x2)
-  }) ->.;
+  }) -> .;
   names(.) <- c("pediagfeatures", "phcolor", "phorizon", "site")
 
 
@@ -164,7 +164,7 @@
   # remove
   temp = temp[!is.na(temp$peiid), - ncol(temp)]
   idx  = names(temp) %in% c("pmkind", "pmorigin")
-  temp[!idx] = uncode(temp[!idx], db = "LIMS")
+  temp[!idx] = uncode(temp[!idx])
   idx  = sapply(temp, is.character)
   temp[idx] = lapply(temp[idx], function(x) ifelse(x == "", NA, x))
   # temp = within(temp, {
@@ -207,7 +207,7 @@
   # NASIS text reports return empty columns
   # remove
   temp = temp[!is.na(temp$peiid), - ncol(temp)]
-  temp = uncode(temp, db = "LIMS")
+  temp = uncode(temp)
   # temp = within(temp, {
   #   obsdate   = as.Date(as.character(obsdate))
   #   classdate = as.Date(as.character(classdate))
@@ -270,7 +270,7 @@
                           pedon_id,
                           hzdept,
                           hzdepb,
-                          rmHzErrors = TRUE,
+                          rmHzErrors = FALSE,
                           nullFragsAreZero = TRUE,
                           soilColorState = "moist"
 ) {
