@@ -6,7 +6,7 @@ getHzErrorsPedonPC <- function(dsn, strict=TRUE) {
 	hz_data <- get_hz_data_from_pedon_db(dsn)
 
 	# combine pieces
-	f <- join(hz_data, site_data, by='peiid', type='inner')
+  f <- merge(hz_data, site_data, by='peiid', all.x = TRUE, sort = FALSE)
 
 	f.test <- aqp::checkHzDepthLogic(f, hzdepths = c('hzdept', 'hzdepb'),
 	                                 idname = 'pedon_id', fast = TRUE)
