@@ -1,7 +1,6 @@
-
 #' @title Retrieve Soil Series Extent Maps from SoilWeb
 #' 
-#' @description This function downloads a generalized representations of a soil series extent from SoilWeb, derived from the current SSURGO snapshot. Data can be returned as vector outlines (\code{SpatialPolygonsDataFrame} object) or gridded representation of area proportion falling within 800m cells (\code{raster} object). Gridded series extent data are only available in CONUS. Vector representations are returned with a GCS/WGS84 coordinate reference system and raster representations are returned with an Albers Equal Area / NAD83 coordinate reference system (EPSG 5070).
+#' @description This function downloads a generalized representations of a soil series extent from SoilWeb, derived from the current SSURGO snapshot. Data can be returned as vector outlines (\code{sf} object) or gridded representation of area proportion falling within 800m cells (\code{SpatRaster} object). Gridded series extent data are only available in CONUS. Vector representations are returned with a GCS/WGS84 coordinate reference system and raster representations are returned with an Albers Equal Area / NAD83 coordinate reference system (`EPSG:5070`).
 #' 
 #' @param s a soil series name, case-insensitive
 #' 
@@ -19,42 +18,44 @@
 #'   
 #' \donttest{
 #' if(requireNamespace("curl") &
+#'    requireNamespace("sf") &
+#'    requireNamespace("terra") &
 #'    curl::has_internet()) {
 #'   
 #'   # required packages
-#'   library(sp)
-#'   library(raster)
-#'   library(rgdal)
+#'   library(sf)
+#'   library(terra)
 #'   
 #'   # specify a soil series name
 #'   s <- 'magnor'
 #'   
-#'   # return as SpatialPolygonsDataFrame
+#'   # return an sf object
 #'   x <- seriesExtent(s, type = 'vector')
-#'   # return as raster
+#'   
+#'   # return a terra SpatRasters
 #'   y <- seriesExtent(s, type = 'raster')
 #'   
-#'   # note that CRS are different
-#'   proj4string(x)
-#'   projection(y)
+#'   if (!is.null(x) && !is.null(y)) {
+#'     # note that CRS are different
+#'     sf::st_crs(x)
+#'     terra::crs(y)
 #'   
-#'   # transform vector representation to CRS of raster
-#'   x <- spTransform(x, CRS(projection(y)))
-#'   
-#'   # graphical comparison
-#'   par(mar = c(1, 1 , 1, 3))
-#'   plot(y, axes = FALSE)
-#'   plot(x, add = TRUE)
+#'     # transform vector representation to CRS of raster
+#'     x <- sf::st_transform(x, terra::crs(y))
 #'   
+#'     # graphical comparison
+#'     par(mar = c(1, 1 , 1, 3))
+#'     plot(y, axes = FALSE)
+#'     
+#'     # no fill color
+#'     plot(x['series'], add = TRUE, col = NA)
+#'   }
 #'   
 #' }
 #' }
 #' 
-
 seriesExtent <- function(s, type = c('vector', 'raster'), timeout = 60) {
-  if(!requireNamespace('rgdal', quietly=TRUE))
-    stop('please install the `rgdal` package', call.=FALSE)
-  
+
   type <- match.arg(type)
   
   # encode series name: spaces -> underscores
@@ -71,6 +72,10 @@ seriesExtent <- function(s, type = c('vector', 'raster'), timeout = 60) {
 }
 
 .vector_extent <- function(s, timeout) {
+  
+  if (!requireNamespace("sf")) 
+    stop("package sf is required to return vector series extent grids", call. = FALSE)
+  
   # base URL to cached data
   u <- URLencode(paste0('https://casoilresource.lawr.ucdavis.edu/series-extent-cache/json/', s, '.json'))
   
@@ -91,18 +96,23 @@ seriesExtent <- function(s, type = c('vector', 'raster'), timeout = 60) {
     return(NULL)
   }
     
-  # load into sp object and clean-up
-  x <- rgdal::readOGR(dsn=tf, verbose=FALSE)
+  # load into sf object and clean-up
+  # can use terra::vect() also
+  x <- sf::st_read(tf, quiet = TRUE)
   unlink(tf)
   
   # reset row names in attribute data to series name
-  x <- spChFIDs(x, as.character(x$series))
+  rownames(x) <- as.character(x$series)
   
   # GCS WGS84
   return(x)
 }
 
 .raster_extent <- function(s, timeout) {
+  
+  if (!requireNamespace("terra")) 
+    stop("package terra is required to return raster series extent grids", call. = FALSE)
+  
   # base URL to cached data
   u <- URLencode(paste0('https://casoilresource.lawr.ucdavis.edu/series-extent-cache/grid/', s, '.tif'))
   
@@ -125,20 +135,21 @@ seriesExtent <- function(s, type = c('vector', 'raster'), timeout = 60) {
     return(NULL)
   }
   
-  ## TODO: suppressing CRS-related warnings (not a problem) until we have a better solution
-  # https://github.com/ncss-tech/soilDB/issues/144
-  # load raster object into memory
-  x <- suppressWarnings(
-    raster(tf, verbose=FALSE)
-  )
-  x <- readAll(x)
+  # init SpatRaster
+  x <- terra::rast(tf)
+  
+  # load all values into memory
+  terra::values(x) <- terra::values(x)
+  
+  # remove tempfile 
+  unlink(tf)
+  
   # transfer layer name
   names(x) <- gsub(pattern='_', replacement=' ', x = s, fixed = TRUE)
   
-  # cleanup
-  unlink(tf)
+  # make CRS explicit
+  terra::crs(x) <- 'EPSG:5070'
   
-  # EPSG:5070
   return(x)
 }
 
